@@ -182,7 +182,7 @@ DoSearch(ManpageGlobals * man_globals, int type)
         strcpy(tmp, MANTEMP);   /* get a temp file. */
         fd = mkstemp(tmp);
         if (fd < 0) {
-            PopupWarning(man_globals, "Cant create temp file");
+            PopupWarning(man_globals, "Can't create temp file");
             return NULL;
         }
         mantmp = tmp;
@@ -207,12 +207,8 @@ DoSearch(ManpageGlobals * man_globals, int type)
         snprintf(label, sizeof(label),
                  "Results of apropos search on: %s", search_string);
 
-#ifdef NO_MANPATH_SUPPORT       /* not quite correct, but the best I can do. */
-        snprintf(cmdbuf, sizeof(cmdbuf), APROPOS_FORMAT, search_string, mantmp);
-#else
         snprintf(cmdbuf, sizeof(cmdbuf), APROPOS_FORMAT, path, search_string,
                  mantmp);
-#endif
 
         if (system(cmdbuf) != 0) {      /* execute search. */
             snprintf(error_buf, sizeof(error_buf),
